==> ads-algorithm-facade-1.0.9.0-sources.jar: com/bxm/adsalgorithm/facade/model/DNNFeatureDto.java <==
package com.bxm.adsalgorithm.facade.model;

import lombok.Data;

import java.io.Serializable;

@Data
public class DNNFeatureDto implements Serializable {

    private static final long serialVersionUID = -3161021124133L;


    private String spm;
    private String bxmId; //发券曝光环节产生
    private String uid; //用户id
    private String settleType; //广告计费类型 1为cpc，2为cpa，默认为1cpc
    private String ip;
    private String userDayLastActivityId; //用户日订单_ 上一单活动ID,
    private String userDayLastPreId; //用户日订单_ 上一单广告ID,
    private String currentGmtCreateTime;  //当前时间
    private String userLastGmtCreateTime; // 用户全局上一单发券曝光时间
    private String userActivityLastGmtCreateTime;//用户全局该活动上一单发券曝光时间
    private Long lastChargeNums; // 全局前一单计费金额  ocpc// 点击了无计费?
    private Long activityLastChargeNums; //当前活动前一单计费金额
    private String preId;  //f1001
    private String ticketTag1; //f1002
    private String ticketTag2;  //f1003
    private String ticketTag3; //f1004
    private String advertiserId; //f1005
    private String accountType;  //广告来源，直客代理';  //f1006
    private String agentId; //代理商 //f1007
    private String assetId; //素材 f1008
    private String[] assetIdArray; //素材id数组
    private String sourceType; //来源 直投、非直投 f1009
    private String mediaId; //f2001
    private String mediaClassId; //媒体一级分类 //f2002
    private String mediaChildClassId; //f2003
    private String providerId; //f2004
    private String mediaSysType; // f2005（媒体）来源类型 (h5 app )
    private String positionId; //广告位id //f2006
    private String positionEntrance; //f2007  广告位入口场景（类别）（banal，浮标）
    private String activityId; //f3001
    private String activityType; //f3002  活动工具类型（标签，奖品类型）
    private String isVenue; //f3003 活动场景（是否主会场）
    private String isAutomaticActivity; // f3004 是否自动发券活动
    private String launchControl; // f3005 活动推出场景（挽留活动场景，正常推荐）
    private String appos; //系统（安卓，ios） //f4004
    private String osType; //系统版本号 andriod7.0 //f4005
    private String browser; //f4007 浏览器
    private String deviceType;  //4008
    private String deviceBrand; //f4009
    private String deviceName; //f4010 手机设备机型
    private String ispDomain; //运营商 //f4012
    private String hw; // f4013 设备分辨率（sh*sw)
    private String province; //f4015
    private String city; //f4016
    private Double ticketStatCtr; //f5001 广告券维度统计CTR特征-24hour,
    private Double mediaStatCtr;  //f5002  媒体维度统计CTR特征-24hour,
    private Double positionStatCtr; // f5003 广告位维度统计CTR特征-24hour,
    private Double activityStatCtr; // f5004 活动维度统计CTR特征-24hour,
    private Double ticketMediaStatCtr; //5005  广告&媒体维度统计CTR特征-24hour,
    private Double ticketPositionStatCtr; //f5006  广告&广告位维度统计CTR特征-24hour,
    private Double ticketActivityStatCtr;  //f5007  广告&活动维度统计CTR特征-24hour,
    private Double providerStatCtr; //f5008 开发者维度统计ctr特征--24hour
    private Double ticketProviderStatCtr; //f5009 广告&开发者维度统计CTR特征-24hour
    private Long userCurrentActivityBxmIdRank; //6001 用户当前活动发券次序（当前这个活动第几次发券）
    private Long userDayBxmIdRank;  //f6002  用户当日发券订单排序,（生成第几个发券曝光订单bxm_id）
    private Long userDayTicketRepeatRank; //f6003  用户当日第几次重复发该券
    private Long userDayActivityBxmIdRank; //f6004 用户当日该活动订单排序,
    private Long userBxmIdRank; //f6005  用户全局发券订单排序,
    private Long userActivityBxmIdRank; //f6006 用户全局该活动订单排序
    private String userLastTicketTag1;  //6009 用户订单_上一单广告券的一级标签
    private String userLastTicketTag2; //f6010
    private String userLastTicketTag3; //6011
    private Long userDayLastActivityIdIfSame; //f6007 用户日订单_当前单与上一单的活动是否相同
    private Long userDayLastPreIdIfSame; // f6008 用户当日订单_上一单广告券id是否相同
    private Long userLastTickeTag1IfSame; //6012 用户订单_当前单与上一单的广告一级标签是否相同,
    private Long userLastTickeTag2IfSame; //f6013
    private Long userLastTickeTag3IfSame; //f6014
    private Long userLastBxmIdIfClick; //f6015 用户全局订单_上一单是否点击计费,
    private Long userActivityIdLastBxmIdIfClick; //f6016 用户全局活动订单_上一单是否点击计费,
    private Long userActivityLastBxmIdIntervelType; //f6017 用户全局活动订单_当前订单与前一单时间差类别,,
    private Long userLastBxmIdIntervelType; //f6018 用户全局订单_当前订单与前一单时间差类别



    private Double ticketStatCvr; //f8020 广告券维度统计CVR特征-24hour,
    private Double mediaStatCvr;  //f8030  媒体维度统计CVR特征-24hour,
    private Double positionStatCvr; // f8040 广告位维度统计CVR特征-24hour,
    private Double activityStatCvr; // f8050 活动维度统计CVR特征-24hour,
    private Double ticketMediaStatCvr; //f8060 广告&媒体维度统计CVR特征-24hour,
    private Double ticketPositionStatCvr; //f8070  广告&广告位维度统计CVR特征-24hour,
    private Double ticketActivityStatCvr;  //f8080  广告&活动维度统计CVR特征-24hour,
    private Double providerStatCvr; //f8090 开发者维度统计cVr特征--24hour
    private Double ticketProviderStatCvr; //f8100 广告&开发者维度统计CVR特征-24hour


}

==> ads-algorithm-facade-1.1.3-sources.jar: com/bxm/adsalgorithm/facade/model/DNNFeatureDto.java <==
package com.bxm.adsalgorithm.facade.model;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

@Data
public class DNNFeatureDto implements Serializable {

    private static final long serialVersionUID = -3161021124133L;


    private String spm;
    private String bxmId; //发券曝光环节产生
    private String uid; //用户id
    private String settleType; //广告计费类型 1为cpc，2为cpa，默认为1cpc
    private String ip;
    private String userDayLastActivityId; //用户日订单_ 上一单活动ID,
    private String userDayLastPreId; //用户日订单_ 上一单广告ID,
    private String currentGmtCreateTime;  //当前时间
    private String userLastGmtCreateTime; // 用户全局上一单发券曝光时间
    private String userActivityLastGmtCreateTime;//用户全局该活动上一单发券曝光时间
    private Long lastChargeNums; // 全局前一单计费金额  ocpc// 点击了无计费?
    private Long activityLastChargeNums; //当前活动前一单计费金额
    private String preId;  //f1001
    private String ticketTag1; //f1002
    private String ticketTag2;  //f1003
    private String ticketTag3; //f1004
    private String advertiserId; //f1005
    private String accountType;  //广告来源，直客代理';  //f1006
    private String agentId; //代理商 //f1007
    private String assetId; //素材 f1008
    private String[] assetIdArray; //素材id数组
    private String sourceType; //来源 直投、非直投 f1009
    private String mediaId; //f2001
    private String mediaClassId; //媒体一级分类 //f2002
    private String mediaChildClassId; //f2003
    private String providerId; //f2004
    private String mediaSysType; // f2005（媒体）来源类型 (h5 app )
    private String positionId; //广告位id //f2006
    private String positionEntrance; //f2007  广告位入口场景（类别）（banal，浮标）
    private String activityId; //f3001
    private String activityType; //f3002  活动工具类型（标签，奖品类型）
    private String isVenue; //f3003 活动场景（是否主会场）
    private String isAutomaticActivity; // f3004 是否自动发券活动
    private String launchControl; // f3005 活动推出场景（挽留活动场景，正常推荐）
    private String appos; //系统（安卓，ios） //f4004
    private String osType; //系统版本号 andriod7.0 //f4005
    private String browser; //f4007 浏览器
    private String deviceType;  //4008
    private String deviceBrand; //f4009
    private String deviceName; //f4010 手机设备机型
    private String ispDomain; //运营商 //f4012
    private String hw; // f4013 设备分辨率（sh*sw)
    private String province; //f4015
    private String city; //f4016
    private Double ticketStatCtr; //f5001 广告券维度统计CTR特征-24hour,
    private Double mediaStatCtr;  //f5002  媒体维度统计CTR特征-24hour,
    private Double positionStatCtr; // f5003 广告位维度统计CTR特征-24hour,
    private Double activityStatCtr; // f5004 活动维度统计CTR特征-24hour,
    private Double ticketMediaStatCtr; //5005  广告&媒体维度统计CTR特征-24hour,
    private Double ticketPositionStatCtr; //f5006  广告&广告位维度统计CTR特征-24hour,
    private Double ticketActivityStatCtr;  //f5007  广告&活动维度统计CTR特征-24hour,
    private Double providerStatCtr; //f5008 开发者维度统计ctr特征--24hour
    private Double ticketProviderStatCtr; //f5009 广告&开发者维度统计CTR特征-24hour
    private Long userCurrentActivityBxmIdRank; //6001 用户当前活动发券次序（当前这个活动第几次发券）
    private Long userDayBxmIdRank;  //f6002  用户当日发券订单排序,（生成第几个发券曝光订单bxm_id）
    private Long userDayTicketRepeatRank; //f6003  用户当日第几次重复发该券
    private Long userDayActivityBxmIdRank; //f6004 用户当日该活动订单排序,
    private Long userBxmIdRank; //f6005  用户全局发券订单排序,
    private Long userActivityBxmIdRank; //f6006 用户全局该活动订单排序
    private String userLastTicketTag1;  //6009 用户订单_上一单广告券的一级标签
    private String userLastTicketTag2; //f6010
    private String userLastTicketTag3; //6011
    private Long userDayLastActivityIdIfSame; //f6007 用户日订单_当前单与上一单的活动是否相同
    private Long userDayLastPreIdIfSame; // f6008 用户当日订单_上一单广告券id是否相同
    private Long userLastTickeTag1IfSame; //6012 用户订单_当前单与上一单的广告一级标签是否相同,
    private Long userLastTickeTag2IfSame; //f6013
    private Long userLastTickeTag3IfSame; //f6014
    private Long userLastBxmIdIfClick; //f6015 用户全局订单_上一单是否点击计费,
    private Long userActivityIdLastBxmIdIfClick; //f6016 用户全局活动订单_上一单是否点击计费,
    private Long userActivityLastBxmIdIntervelType; //f6017 用户全局活动订单_当前订单与前一单时间差类别,,
    private Long userLastBxmIdIntervelType; //f6018 用户全局订单_当前订单与前一单时间差类别



    private Double ticketStatCvr; //f8020 广告券维度统计CVR特征-24hour,
    private Double mediaStatCvr;  //f8030  媒体维度统计CVR特征-24hour,
    private Double positionStatCvr; // f8040 广告位维度统计CVR特征-24hour,
    private Double activityStatCvr; // f8050 活动维度统计CVR特征-24hour,
    private Double ticketMediaStatCvr; //f8060 广告&媒体维度统计CVR特征-24hour,
    private Double ticketPositionStatCvr; //f8070  广告&广告位维度统计CVR特征-24hour,
    private Double ticketActivityStatCvr;  //f8080  广告&活动维度统计CVR特征-24hour,
    private Double providerStatCvr; //f8090 开发者维度统计cVr特征--24hour
    private Double ticketProviderStatCvr; //f8100 广告&开发者维度统计CVR特征-24hour


    //行为轨迹
    private List<UserBehaviorTrace> userBehaviorTraceList;
    private List<UserBehaviorTrace> userBehaviorTraceListCVR1;
    private List<UserBehaviorTrace> userBehaviorTraceListCVR2;
    private List<String> appList;

    //ocpc当前阶段
    private String ocpcType;

    //素材的所有特征
    private List<TicketAssetsFeatureDto> assetsList;
}
